"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createConfig = exports.createConfigDescriptor = void 0;
/**
 * get package names from package.json
 */
const getSecretLintPackageNames = (packageJSON) => {
    const dependencies = packageJSON.dependencies || {};
    const devDependencies = packageJSON.devDependencies || {};
    const mergedDependencies = Object.assign(Object.assign({}, dependencies), devDependencies);
    const pkgNames = Object.keys(mergedDependencies);
    return pkgNames.filter((pkgName) => {
        // secretlint-rule- or @scope/secretlint-rule
        return pkgName.startsWith("secretlint-rule-") || pkgName.includes("/secretlint-rule-");
    });
};
/**
 * create config descriptor from rule names
 */
const createConfigDescriptor = ({ ruleNames }) => {
    return {
        rules: ruleNames.map((name) => {
            return {
                id: name,
            };
        }),
    };
};
exports.createConfigDescriptor = createConfigDescriptor;
/**
 * Create Config Object from package.json
 */
const createConfig = (options) => {
    const ruleNames = getSecretLintPackageNames(options.packageJSON);
    return exports.createConfigDescriptor({ ruleNames: ruleNames });
};
exports.createConfig = createConfig;
//# sourceMappingURL=index.js.map